@@ -586,8 +586,7 @@ class PluginsStore(SharedState, EnvAble):
 
 # --------------------------------------------------SPECIAL TYPES------------------------------------------------------
 
-@dataclass
-class SocketConf:
+class SocketConf(BaseModel):
     host: str | None
     port: int | None
 
@@ -623,8 +622,7 @@ GenISocket = TypeVar("GenISocket", bound=ISocket)
 GenCommunicator = TypeVar("GenCommunicator")
 
 
-@dataclass
-class TransportConf:
+class TransportConf(BaseModel):
     socket: SocketConf
 
 
